package VMOMI::DistributedVirtualSwitchProductSpecOperationType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
